# `okdata-cli`: Oslo Origo data services CLI

Okdata CLI provides a unified interface to data services for Oslo Origo teams.

* [Install](doc/install.md)
* [Configuration](doc/configuration.md)
* [Datasets](doc/datasets.md)
* [Permissions](doc/permissions.md)
* [Pipelines](doc/pipelines.md)
* [Public registers](doc/pubreg.md)
* [Teams](doc/teams.md)
